# m

## install

### pypi

```
pip install jmlopez-m
```

### npmjs

```
pnpm add @jmlopez/m
```

### github

```
pnpm add @jmlopez-rod/m
```

Before running the command make sure to have the following in the project
`.npmrc` or `~/.npmrc`.

```
@jmlopez-rod:registry=https://npm.pkg.github.com/
//npm.pkg.github.com/:_authToken=${GITHUB_TOKEN}
```

Make sure to have `GITHUB_TOKEN` defined in your environment variables with
a valid token obtained from <https://github.com/settings/tokens>.
